package com.zhyc.module.sale.service;

import java.util.List;
import com.zhyc.module.sale.domain.SxCustomer;

public interface ISxCustomerService {
    SxCustomer selectSxCustomerById(Long id);
    List<SxCustomer> selectSxCustomerList(SxCustomer sxCustomer);
    int insertSxCustomer(SxCustomer sxCustomer);
    int updateSxCustomer(SxCustomer sxCustomer);
    int deleteSxCustomerByIds(Long[] ids);
    int deleteSxCustomerById(Long id);
}
